"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SyntaxHighlighter = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _SyntaxContext = require("./SyntaxContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable no-console */

const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[SyntaxHighlighter]', ...args);
}
const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
const SyntaxHighlighter = exports.SyntaxHighlighter = /*#__PURE__*/(0, _react.memo)(({
  code,
  language,
  theme,
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = (0, _SyntaxContext.useShiki)();
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)(null);
  const highlight = (0, _react.useCallback)(async () => {
    if (!highlighter || !isReady) {
      _log('Highlighter not ready:', {
        highlighter: !!highlighter,
        isReady
      });
      return;
    }
    try {
      const loadedLangs = highlighter.getLoadedLanguages();
      _log('Available languages:', loadedLangs);
      const normalizedLang = language?.toLowerCase() || 'text';
      _log('Requested language:', normalizedLang);
      const langToUse = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      _log('Using language:', langToUse);

      // Get theme name
      const themeName = typeof theme === 'string' ? theme : theme?.name || 'github-dark';

      // Validate theme is loaded
      const loadedThemes = highlighter.getLoadedThemes();
      if (!loadedThemes.includes(themeName)) {
        throw new Error(`Theme ${themeName} not loaded. Available themes: ${loadedThemes.join(', ')}`);
      }

      // Get complete theme details
      const currentTheme = highlighter.getTheme(themeName);
      _log('Theme details:', {
        name: currentTheme.name,
        type: currentTheme.type,
        tokenColors: currentTheme.tokenColors?.length,
        settings: currentTheme.settings?.length,
        firstTokenColor: currentTheme.tokenColors?.[0]
      });

      // Use codeToTokens with explanation to debug token mapping
      const results = highlighter.codeToTokens(code.trim(), {
        lang: langToUse,
        theme: themeName,
        includeExplanation: true
      });

      // In SyntaxHighlighter.tsx
      _log('Tokenization results:', {
        lineCount: results.tokens.length,
        totalTokens: results.tokens.flat().length,
        firstLine: results.tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          fontStyle: t.fontStyle,
          scopes: t.explanation?.[0]?.scopes.map(s => ({
            scope: s.scopeName,
            matches: s.themeMatches?.map(m => ({
              scope: m.scope,
              settings: m.settings
            }))
          }))
        })),
        uniqueColors: [...new Set(results.tokens.flat().map(t => t.color))]
      });
      setTokens(results.tokens);
      setError(null);
    } catch (err) {
      console.error('Highlighting error:', err);
      _log('Highlighting failed:', {
        error: err instanceof Error ? err.message : 'Unknown error',
        code: `${code.substring(0, 100)}...`
      });
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
    }
  }, [code, language, theme, highlighter, isReady]);
  (0, _react.useEffect)(() => {
    highlight();
  }, [highlight]);
  (0, _react.useEffect)(() => {
    if (tokens.length > 0) {
      _log('Token analysis:', {
        lineCount: tokens.length,
        sample: tokens[0]?.slice(0, 2),
        colors: [...new Set(tokens.flat().map(t => t.color))]
      });
    }
  }, [tokens]);
  if (!isReady) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: styles.container,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: styles.container,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    style: styles.container,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((line, i) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.line,
        children: line.map((token, j) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
          style: {
            color: token.color,
            fontSize,
            ...(token.fontStyle && token.fontStyle & 1 && {
              fontStyle: 'italic'
            }),
            ...(token.fontStyle && token.fontStyle & 2 && {
              fontWeight: 'bold'
            }),
            ...(token.bgColor && {
              backgroundColor: token.bgColor
            })
          },
          children: token.content
        }, `${i}-${j}`))
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map