/* eslint-disable no-console */
import type { StringLiteralUnion, ThemeRegistrationAny } from '@shikijs/types'
import type { TextStyle } from 'react-native'

const DEBUG = true
function log(...args: any[]) {
  if (DEBUG) {
    console.log('[StyleUtils]', ...args)
  }
}

export interface ShikiStyleSheet {
  root: TextStyle
}

export function getStylesFromShikiTheme(theme: ThemeRegistrationAny | StringLiteralUnion<string>): ShikiStyleSheet {
  // Convert string theme to ThemeRegistrationAny
  const themeReg: ThemeRegistrationAny
    = typeof theme === 'string'
      ? {
          name: theme,
          type: 'dark', // Default to dark theme
          colors: {},
        }
      : theme

  log('Processing theme:', {
    name: themeReg.name,
    type: themeReg.type,
    colors: themeReg.colors,
  })

  // We only need the root styles since Shiki handles token colors
  const styles: ShikiStyleSheet = {
    root: {
      backgroundColor: themeReg.bg || themeReg.colors?.['editor.background'],
      color: themeReg.fg || themeReg.colors?.['editor.foreground'],
    },
  }

  log('Generated root style:', styles.root)

  return styles
}
